Crate kcr_multicluster_x_k8s_io

Crate kcr_multicluster_x_k8s_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the multicluster.x-k8s.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

multicluster.x-k8s.io/v1alpha1

  • ServiceExport
  • ServiceImport
  • AppliedWork
  • Work

Modules

v1alpha1