This crate contains kube-rs compatible bindings for Kubernetes custom resources for the multicluster.x-k8s.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
multicluster.x-k8s.io/v1alpha1
ServiceExportServiceImportAppliedWorkWork